@@ -22,7 +22,6 @@
 
 #include <QObject>
 
-class KJob;
 
 /**
   This class uses the SendQueuedAction to mark all queued messages in the
@@ -35,10 +34,9 @@ class Runner : public QObject
   public:
     Runner();
 
-  private slots:
+  private Q_SLOTS:
     void checkFolders();
 
 };
 
-
 #endif
